@@ -32,7 +32,7 @@ def hypersphere_surface_sample(center,radius,k=1):
 
 
 def squared_distance(p0, p1):
-    return np.sum((p0-p1)*(p0-p1))
+    return np.sum(np.square(p0-p1))
 
 def Bridson_sampling(dims=np.array([1.0,1.0]), radius=0.05, k=30, hypersphere_sample=hypersphere_volume_sample):
     # References: Fast Poisson Disk Sampling in Arbitrary Dimensions
@@ -54,22 +54,25 @@ def Bridson_sampling(dims=np.array([1.0,1.0]), radius=0.05, k=30, hypersphere_sa
     def in_limits(p):
         return np.all(np.zeros(ndim) <= p) and np.all(p < dims)
 
+    # Check if there are samples closer than "squared_radius" to the candidate "p"
     def in_neighborhood(p, n=2):
-        indices = (p/cellsize).astype(int)
-        indmin = np.maximum(indices-n, np.zeros(ndim, dtype=int))
-        indmax = np.minimum(indices+n+1, gridsize)
-        if M[tuple(indices)]:
+        indices = (p / cellsize).astype(int)
+        indmin = np.maximum(indices - n, np.zeros(ndim, dtype=int))
+        indmax = np.minimum(indices + n + 1, gridsize)
+        
+        # Check if the center cell is empty
+        if not np.isnan(P[tuple(indices)][0]):
             return True
-        for offset in np.ndindex(tuple(indmax - indmin)):
-            indcur = tuple([sum(x) for x in zip(indmin,offset)])
-            if M[indcur] and squared_distance(p, P[indcur]) < squared_radius:
-                return True
-        return False
-
+        a = []
+        for i in range(ndim):
+            a.append(slice(indmin[i], indmax[i]))
+        if np.any(np.sum(np.square(p - P[tuple(a)]), axis=ndim) < squared_radius):
+            return True
+    
     def add_point(p):
         points.append(p)
         indices = (p/cellsize).astype(int)
-        P[tuple(indices)], M[tuple(indices)] = p, True
+        P[tuple(indices)] = p
 
     cellsize = radius/np.sqrt(ndim)
     gridsize = (np.ceil(dims/cellsize)).astype(int)
@@ -78,8 +81,9 @@ def Bridson_sampling(dims=np.array([1.0,1.0]), radius=0.05, k=30, hypersphere_sa
     squared_radius = radius*radius
 
     # Positions of cells
-    P = np.zeros(np.append(gridsize, ndim), dtype=np.float32) #n-dim value for each grid cell
-    M = np.zeros(gridsize, dtype=bool)
+    P = np.empty(np.append(gridsize, ndim), dtype=np.float32) #n-dim value for each grid cell
+    # Initialise empty cells with NaNs
+    P.fill(np.nan)
 
     points = []
     add_point(np.random.uniform(np.zeros(ndim), dims))
@@ -91,4 +95,4 @@ def Bridson_sampling(dims=np.array([1.0,1.0]), radius=0.05, k=30, hypersphere_sa
         for q in Q:
             if in_limits(q) and not in_neighborhood(q):
                 add_point(q)
-    return P[M]
+    return P[~np.isnan(P).any(axis=ndim)]
